@@ -250,6 +250,7 @@ Bool
 G80DispInit(ScrnInfoPtr pScrn)
 {
     G80Ptr pNv = G80PTR(pScrn);
+    CARD32 val;
 
     if(pNv->reg[0x00610024/4] & 0x100) {
         pNv->reg[0x00610024/4] = 0x100;
@@ -258,7 +259,15 @@ G80DispInit(ScrnInfoPtr pScrn)
     }
 
     pNv->reg[0x00610200/4] = 0x2b00;
-    while((pNv->reg[0x00610200/4] & 0x1e0000) != 0);
+    do {
+        val = pNv->reg[0x00610200/4];
+
+        if ((val & 0x9f0000) == 0x20000)
+            pNv->reg[0x00610200/4] = val | 0x800000;
+
+        if ((val & 0x3f0000) == 0x30000)
+            pNv->reg[0x00610200/4] = val | 0x200000;
+    } while ((val & 0x1e0000) != 0);
     pNv->reg[0x00610300/4] = 1;
     pNv->reg[0x00610200/4] = 0x1000b03;
     while(!(pNv->reg[0x00610200/4] & 0x40000000));
@@ -398,7 +407,7 @@ G80CrtcBlankScreen(xf86CrtcPtr crtc, Bool blank)
         C(0x00000860 + headOff, 0);
         C(0x00000864 + headOff, 0);
         pNv->reg[0x00610380/4] = 0;
-        pNv->reg[0x00610384/4] = pNv->RamAmountKBytes * 1024 - 1;
+        pNv->reg[0x00610384/4] = pNv->videoRam * 1024 - 1;
         pNv->reg[0x00610388/4] = 0x150000;
         pNv->reg[0x0061038C/4] = 0;
         C(0x00000884 + headOff, (pNv->videoRam << 2) - 0x40);
@@ -414,7 +423,7 @@ G80CrtcBlankScreen(xf86CrtcPtr crtc, Bool blank)
     }
 }
 
-void
+static void
 G80CrtcDPMSSet(xf86CrtcPtr crtc, int mode)
 {
 }
@@ -433,12 +442,12 @@ static void G80CrtcShowHideCursor(xf86CrtcPtr crtc, Bool show, Bool update)
     }
 }
 
-void G80CrtcShowCursor(xf86CrtcPtr crtc)
+static void G80CrtcShowCursor(xf86CrtcPtr crtc)
 {
     G80CrtcShowHideCursor(crtc, TRUE, TRUE);
 }
 
-void G80CrtcHideCursor(xf86CrtcPtr crtc)
+static void G80CrtcHideCursor(xf86CrtcPtr crtc)
 {
     G80CrtcShowHideCursor(crtc, FALSE, TRUE);
 }
